weaviate.data.references package
================================

.. automodule:: weaviate.data.references
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

weaviate.data.references.crud\_references module
------------------------------------------------

.. automodule:: weaviate.data.references.crud_references
   :members:
   :undoc-members:
   :show-inheritance:
